@@ -1,11 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+*/
 
 #include "selectsecretkey.h"
 
@@ -104,10 +101,6 @@ KgpgSelectSecretKey::KgpgSelectSecretKey(QWidget *parent, KGpgItemModel *model,
 	connect(m_keyslist, &QTableView::doubleClicked, this, &KgpgSelectSecretKey::slotOk);
 }
 
-KgpgSelectSecretKey::~KgpgSelectSecretKey()
-{
-}
-
 QString KgpgSelectSecretKey::getKeyID() const
 {
     if (!m_keyslist->selectionModel()->hasSelection())
